{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "FragGeneScan: find (fragmented) genes in short reads",
            "doc": "FragGeneScan is an application for finding (fragmented) genes in short\nreads. It can also be applied to predict prokaryotic genes in incomplete\nassemblies or complete genomes.\n\nFragGeneScan was first released through omics website (http://omics.informatics.indiana.edu/FragGeneScan/)\nin March 2010, where you can find its old releases. FragGeneScan migrated to SourceForge in October, 2013\n(https://sourceforge.net/projects/fraggenescan/).\n\nVersion 1.20 can be downloaded here:\nhttps://sourceforge.net/projects/fraggenescan/files/\n",
            "baseCommand": [],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "types": [
                        {
                            "type": "record",
                            "name": "#FragGeneScan-model.yaml/model",
                            "fields": [
                                {
                                    "name": "#FragGeneScan-model.yaml/model/main",
                                    "type": "File"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_forward",
                                    "type": "File",
                                    "label": "Forward probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_backward",
                                    "type": "File",
                                    "label": "Backward probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_noncoding",
                                    "type": "File",
                                    "label": "Noncoding probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_start",
                                    "type": "File",
                                    "label": "Start probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_stop",
                                    "type": "File",
                                    "label": "Stop probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_start1",
                                    "type": "File",
                                    "label": "Start1 probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_stop1",
                                    "type": "File",
                                    "label": "Stop1 probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/pwm_dist",
                                    "type": "File",
                                    "label": "pwm distribution"
                                }
                            ]
                        }
                    ],
                    "class": "SchemaDefRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_011929"
                            ],
                            "version": [
                                "1.20"
                            ],
                            "package": "fraggenescan"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "doc": "True if the sequence file has complete genomic sequences\nFalse if the sequence file has short sequence reads\n",
                    "type": "boolean",
                    "inputBinding": {
                        "valueFrom": "${ if (self) {\n     return [ \"-w\", \"1\" ];\n   } else {\n     return [ \"-w\", \"0\" ];\n   }\n }\n"
                    },
                    "id": "#FragGeneScan1_20.cwl/completeSeq"
                },
                {
                    "type": "#FragGeneScan-model.yaml/model",
                    "id": "#FragGeneScan1_20.cwl/model"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "prefix": "-s"
                    },
                    "id": "#FragGeneScan1_20.cwl/sequence"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-p"
                    },
                    "id": "#FragGeneScan1_20.cwl/threadNumber"
                }
            ],
            "arguments": [
                "mkdir",
                "train",
                ";",
                "ln",
                "-s",
                "$(inputs.model.main.path)",
                "train/",
                ";",
                "ln",
                "-s",
                "$(inputs.model.prob_forward.path)",
                "train/gene",
                ";",
                "ln",
                "-s",
                "$(inputs.model.prob_backward.path)",
                "train/rgene",
                ";",
                "ln",
                "-s",
                "$(inputs.model.prob_noncoding.path)",
                "train/noncoding",
                ";",
                "ln",
                "-s",
                "$(inputs.model.prob_start.path)",
                "train/start",
                ";",
                "ln",
                "-s",
                "$(inputs.model.prob_stop.path)",
                "train/stop",
                ";",
                "ln",
                "-s",
                "$(inputs.model.prob_start1.path)",
                "train/start1",
                ";",
                "ln",
                "-s",
                "$(inputs.model.prob_stop1.path)",
                "train/stop1",
                ";",
                "ln",
                "-s",
                "$(inputs.model.pwm_dist.path)",
                "train/pwm",
                ";",
                "FragGeneScan",
                "-o",
                "$(runtime.outdir)/predicted_cds",
                "-t",
                "train/$(inputs.model.main.basename)"
            ],
            "id": "#FragGeneScan1_20.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "predicted_cds.faa"
                    },
                    "id": "#FragGeneScan1_20.cwl/predictedCDS"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "InterProScan: protein sequence classifier",
            "doc": "Version 5.21-60 can be downloaded here:\nhttps://github.com/ebi-pf-team/interproscan/wiki/HowToDownload\n\nDocumentation on how to run InterProScan 5 can be found here:\nhttps://github.com/ebi-pf-team/interproscan/wiki/HowToRun\n",
            "requirements": [
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "type": "enum",
                            "name": "#InterProScan-apps.yaml/apps",
                            "symbols": [
                                "#InterProScan-apps.yaml/apps/TIGRFAM",
                                "#InterProScan-apps.yaml/apps/SFLD",
                                "#InterProScan-apps.yaml/apps/SUPERFAMILY",
                                "#InterProScan-apps.yaml/apps/Gene3D",
                                "#InterProScan-apps.yaml/apps/Hamap",
                                "#InterProScan-apps.yaml/apps/Coils",
                                "#InterProScan-apps.yaml/apps/ProSiteProfiles",
                                "#InterProScan-apps.yaml/apps/SMART",
                                "#InterProScan-apps.yaml/apps/CDD",
                                "#InterProScan-apps.yaml/apps/PRINTS",
                                "#InterProScan-apps.yaml/apps/PIRSF",
                                "#InterProScan-apps.yaml/apps/ProSitePatterns",
                                "#InterProScan-apps.yaml/apps/Pfam",
                                "#InterProScan-apps.yaml/apps/ProDom",
                                "#InterProScan-apps.yaml/apps/MobiDBLite"
                            ]
                        },
                        {
                            "type": "enum",
                            "name": "#InterProScan-protein_formats.yaml/protein_formats",
                            "symbols": [
                                "#InterProScan-protein_formats.yaml/protein_formats/TSV",
                                "#InterProScan-protein_formats.yaml/protein_formats/XML",
                                "#InterProScan-protein_formats.yaml/protein_formats/GFF3"
                            ]
                        }
                    ]
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_005829"
                            ],
                            "version": [
                                "5.21-60"
                            ],
                            "package": "interproscan"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "#InterProScan-apps.yaml/apps"
                        }
                    ],
                    "inputBinding": {
                        "itemSeparator": ",",
                        "prefix": "--applications"
                    },
                    "id": "#InterProScan5.21-60.cwl/applications"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input"
                    },
                    "id": "#InterProScan5.21-60.cwl/proteinFile"
                }
            ],
            "baseCommand": "interproscan.sh",
            "arguments": [
                {
                    "valueFrom": "i5_annotations",
                    "prefix": "--outfile"
                },
                {
                    "valueFrom": "TSV",
                    "prefix": "--formats"
                },
                "--disable-precalc",
                "--goterms",
                "--pathways",
                {
                    "valueFrom": "$(runtime.tmpdir)",
                    "prefix": "--tempdir"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "i5_annotations"
                    },
                    "id": "#InterProScan5.21-60.cwl/i5Annotations"
                }
            ],
            "id": "#InterProScan5.21-60.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "inputs": [
                {
                    "type": "File",
                    "label": "output of infernal's cmscan or cmsearch",
                    "id": "#SSU-from-tablehits.cwl/table_hits"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#SSU-from-tablehits.cwl/extract_coords/matched_seqs_with_coords",
                    "id": "#SSU-from-tablehits.cwl/SSU_coordinates"
                }
            ],
            "steps": [
                {
                    "run": "#extract-coords-from-cmscan.cwl",
                    "in": [
                        {
                            "source": "#SSU-from-tablehits.cwl/grep/SSUs",
                            "id": "#SSU-from-tablehits.cwl/extract_coords/infernal_matches"
                        }
                    ],
                    "out": [
                        "#SSU-from-tablehits.cwl/extract_coords/matched_seqs_with_coords"
                    ],
                    "id": "#SSU-from-tablehits.cwl/extract_coords"
                },
                {
                    "run": "#pull-SSUs.cwl",
                    "in": [
                        {
                            "source": "#SSU-from-tablehits.cwl/table_hits",
                            "id": "#SSU-from-tablehits.cwl/grep/hits"
                        }
                    ],
                    "out": [
                        "#SSU-from-tablehits.cwl/grep/SSUs"
                    ],
                    "id": "#SSU-from-tablehits.cwl/grep"
                }
            ],
            "id": "#SSU-from-tablehits.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "normalize to fasta",
            "doc": "normalizes input sequeces to FASTA with fixed number of sequence characters\nper line using esl-reformat from https://github.com/EddyRivasLab/easel\n",
            "requirements": [
                {
                    "types": [
                        {
                            "type": "record",
                            "name": "#esl-reformat-replace.yaml/replace",
                            "label": "sequence token replacement",
                            "fields": [
                                {
                                    "name": "#esl-reformat-replace.yaml/replace/find",
                                    "type": "string",
                                    "label": null,
                                    "doc": "Must be equal length with \"replace\". Each character from the input file\nwill be replaced by its counterpart (at the same position) from \"replace\"\n"
                                },
                                {
                                    "name": "#esl-reformat-replace.yaml/replace/replace",
                                    "type": "string",
                                    "label": null,
                                    "doc": "must be equal length with \"find\""
                                }
                            ]
                        }
                    ],
                    "class": "SchemaDefRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "#esl-reformat-replace.yaml/replace"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--replace",
                        "valueFrom": "$(self.find):$(self.replace)"
                    },
                    "id": "#esl-reformat.cwl/replace"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "format": [
                        "http://edamontology.org/format_1930",
                        "http://edamontology.org/format_1929",
                        "http://edamontology.org/format_1927",
                        "http://edamontology.org/format_1936",
                        "http://edamontology.org/format_1961",
                        "http://edamontology.org/format_1963"
                    ],
                    "id": "#esl-reformat.cwl/sequences"
                }
            ],
            "baseCommand": [
                "esl-reformat"
            ],
            "arguments": [
                {
                    "valueFrom": "fasta",
                    "position": 2
                }
            ],
            "stdout": "reformatted_sequences",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#esl-reformat.cwl/reformatted_sequences",
                    "outputBinding": {
                        "glob": "reformatted_sequences"
                    }
                }
            ],
            "id": "#esl-reformat.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "index a sequence file for use by esl-sfetch",
            "doc": "https://github.com/EddyRivasLab/easel",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 10,
                        "valueFrom": "$(self.basename)"
                    },
                    "format": [
                        "http://edamontology.org/format_1929",
                        "http://edamontology.org/format_1927",
                        "http://edamontology.org/format_1936",
                        "http://edamontology.org/format_1961",
                        "http://edamontology.org/format_1963"
                    ],
                    "id": "#esl-sfetch-index.cwl/sequences"
                }
            ],
            "baseCommand": [],
            "arguments": [
                "cp",
                "$(inputs.sequences.path)",
                "$(runtime.outdir)",
                {
                    "valueFrom": ";",
                    "shellQuote": false
                },
                "esl-sfetch",
                "--index"
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": ".ssi",
                    "format": "$(inputs.sequences.format)",
                    "outputBinding": {
                        "glob": "$(inputs.sequences.basename)"
                    },
                    "id": "#esl-sfetch-index.cwl/sequences_with_index"
                }
            ],
            "id": "#esl-sfetch-index.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "extract by names from an indexed sequence file",
            "doc": "https://github.com/EddyRivasLab/easel",
            "inputs": [
                {
                    "label": "sequence file indexed by esl-sfetch-index",
                    "type": "File",
                    "secondaryFiles": ".ssi",
                    "inputBinding": {
                        "prefix": "-f",
                        "position": 1
                    },
                    "format": [
                        "http://edamontology.org/format_1929",
                        "http://edamontology.org/format_1927",
                        "http://edamontology.org/format_1936",
                        "http://edamontology.org/format_1961",
                        "http://edamontology.org/format_1963"
                    ],
                    "id": "#esl-sfetch-manyseqs.cwl/indexed_sequences"
                },
                {
                    "type": "File",
                    "label": "sequence names to retrieve, one per line",
                    "streamable": true,
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#esl-sfetch-manyseqs.cwl/names"
                },
                {
                    "doc": "GDF format: <newname> <from> <to> <source seqname>\nspace/tabdelimited\n",
                    "type": "boolean",
                    "inputBinding": {
                        "prefix": "-C"
                    },
                    "id": "#esl-sfetch-manyseqs.cwl/names_contain_subseq_coords"
                }
            ],
            "baseCommand": [
                "esl-sfetch"
            ],
            "stdout": "sequences",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#esl-sfetch-manyseqs.cwl/sequences",
                    "outputBinding": {
                        "glob": "sequences"
                    }
                }
            ],
            "id": "#esl-sfetch-manyseqs.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "inputs": [
                {
                    "label": "output from infernal cmscan or cmsearch",
                    "type": "File",
                    "streamable": true,
                    "id": "#extract-coords-from-cmscan.cwl/infernal_matches"
                }
            ],
            "baseCommand": "awk",
            "stdout": "matched_seqs_with_coords",
            "arguments": [
                "{print $4\"-\"$3\"/\"$10\"-\"$11\" \"$10\" \"$11\" \"$4}",
                "$(inputs.infernal_matches.path)"
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#extract-coords-from-cmscan.cwl/matched_seqs_with_coords",
                    "outputBinding": {
                        "glob": "matched_seqs_with_coords"
                    }
                }
            ],
            "doc": "The awk script takes the output of Infernal's cm{scan,search} fmt=2 mode and\nmakes it suitable for use by esl-sfetch, a sequence selector\n\nReading the user's guide for Infernal, Version 1.1.2; July 2016\nhttp://eddylab.org/infernal/Userguide.pdf#page=60 we see that\nthe relevant fields in the cmscan output are:\n(fmt2 column number: explanation)\n3: The accession of the target sequence or profile, or \u2019-\u2019 if none\n4: The name of the query sequence or profile \n10: The start of the alignment of this hit with respect to the\n    sequence, numbered 1..L for a sequence of L residues.\n11: The end of the alignment of this hit with respect to the sequence,\n    numbered 1..L for a sequence of L residues\n\nLikewise the format esl-sfetch wants is: <newname> <from> <to> <source seqname>\n\nPutting it all together we see that the newname (which esl-sfetch with\noutput using) is a concatenation of the original name, the sequence\nnumber, and the coordinates.\n",
            "id": "#extract-coords-from-cmscan.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "search sequence(s) against a covariance model database",
            "doc": "http://eddylab.org/infernal/Userguide.pdf",
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_011809"
                            ],
                            "version": [
                                "1.1.2"
                            ],
                            "package": "infernal"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "label": "clan information on the models provided",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--clanin"
                    },
                    "doc": "Not all models provided need to be a member of a clan",
                    "id": "#infernal-cmscan.cwl/clan_information"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "secondaryFiles": [
                        ".i1f",
                        ".i1i",
                        ".i1m",
                        ".i1p"
                    ],
                    "id": "#infernal-cmscan.cwl/covariance_model_database"
                },
                {
                    "label": "use CM's GA gathering cutoffs as reporting thresholds",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "inputBinding": {
                        "prefix": "--cut_ga"
                    },
                    "id": "#infernal-cmscan.cwl/cut_ga"
                },
                {
                    "label": "Omit the alignment section from the main output.",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "inputBinding": {
                        "prefix": "--noali"
                    },
                    "doc": "This can greatly reduce the output volume.",
                    "id": "#infernal-cmscan.cwl/omit_alignment_section"
                },
                {
                    "label": "Only use the filter profile HMM for searches, do not use the CM",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "inputBinding": {
                        "prefix": "--hmmonly"
                    },
                    "doc": "Only filter stages F1 through F3 will be executed, using strict P-value\nthresholds (0.02 for F1, 0.001 for F2 and 0.00001 for F3). Additionally\na bias composition filter is used after the F1 stage (with P=0.02\nsurvival threshold).  Any hit that survives all stages and has an HMM\nE-value or bit score above the reporting threshold will be output. \n",
                    "id": "#infernal-cmscan.cwl/only_hmm"
                },
                {
                    "label": "do not output lower scoring overlaps",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "inputBinding": {
                        "prefix": "--oskip"
                    },
                    "id": "#infernal-cmscan.cwl/oskip"
                },
                {
                    "type": "File",
                    "streamable": true,
                    "inputBinding": {
                        "position": 1
                    },
                    "format": [
                        "http://edamontology.org/format_1929",
                        "http://edamontology.org/format_1927",
                        "http://edamontology.org/format_1936",
                        "http://edamontology.org/format_1961",
                        "http://edamontology.org/format_3281",
                        "http://edamontology.org/format_1982",
                        "http://edamontology.org/format_1997"
                    ],
                    "id": "#infernal-cmscan.cwl/query_sequences"
                }
            ],
            "baseCommand": "cmscan",
            "arguments": [
                {
                    "valueFrom": "2",
                    "prefix": "--fmt"
                },
                {
                    "valueFrom": "matches.tbl",
                    "prefix": "--tblout"
                },
                {
                    "valueFrom": "$(runtime.cores)",
                    "prefix": "--cpu"
                }
            ],
            "outputs": [
                {
                    "label": "target hits table, format 2",
                    "doc": "http://eddylab.org/infernal/Userguide.pdf#page=60",
                    "type": "File",
                    "outputBinding": {
                        "glob": "matches.tbl"
                    },
                    "id": "#infernal-cmscan.cwl/matches"
                }
            ],
            "id": "#infernal-cmscan.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "MAPseq",
            "doc": "sequence read classification tools designed to assign taxonomy and OTU\nclassifications to ribosomal RNA sequences.\nhttp://meringlab.org/software/mapseq/\n",
            "hints": [
                {
                    "packages": [
                        {
                            "version": [
                                "1.0"
                            ],
                            "package": "mapseq"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": ".mscluster",
                    "inputBinding": {
                        "position": 2
                    },
                    "format": "http://edamontology.org/format_1929",
                    "id": "#mapseq.cwl/database"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "format": "http://edamontology.org/format_1929",
                    "id": "#mapseq.cwl/sequences"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#mapseq.cwl/taxonomies"
                }
            ],
            "baseCommand": "mapseq",
            "arguments": [
                {
                    "valueFrom": "4",
                    "prefix": "-nthreads"
                }
            ],
            "stdout": "classifications",
            "outputs": [
                {
                    "type": "File",
                    "format": "#mapseq.cwl/text/tab-separated-values",
                    "id": "#mapseq.cwl/classifications",
                    "outputBinding": {
                        "glob": "classifications"
                    }
                }
            ],
            "id": "#mapseq.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "metaSPAdes: de novo metagenomics assembler",
            "doc": "https://arxiv.org/abs/1604.03071\nhttp://cab.spbu.ru/files/release3.10.1/manual.html#meta\n",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "ramMin": 102400,
                    "class": "ResourceRequirement"
                },
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_000131"
                            ],
                            "version": [
                                "3.10.1"
                            ],
                            "package": "spades"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "inputBinding": {
                        "prefix": "-1"
                    },
                    "id": "#metaspades.cwl/forward_reads"
                },
                {
                    "label": "Set memory limit in Gb",
                    "doc": "SPAdes terminates if it reaches this limit. Actual amount of consumed\nRAM will be below this limit. Make sure the provided value is correct for\nthe given machine. SPAdes uses the limit value to automatically determine\nthe sizes of various buffers, etc.\n",
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--memory"
                    },
                    "id": "#metaspades.cwl/memory_limit"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "inputBinding": {
                        "prefix": "-2"
                    },
                    "id": "#metaspades.cwl/reverse_reads"
                },
                {
                    "label": "Number of threads",
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 1,
                    "inputBinding": {
                        "prefix": "--threads"
                    },
                    "id": "#metaspades.cwl/threads"
                }
            ],
            "baseCommand": [
                "metaspades.py"
            ],
            "arguments": [
                "-o",
                "$(runtime.outdir)",
                "--tmp-dir",
                "$(runtime.tmpdir)"
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "assembly_graph.fastg"
                    },
                    "id": "#metaspades.cwl/assembly_graph"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "contigs.fasta"
                    },
                    "id": "#metaspades.cwl/contigs"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "contigs.paths"
                    },
                    "id": "#metaspades.cwl/contigs_assembly_graph"
                },
                {
                    "label": "contigs before repeat resolution",
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "before_rr.fasta"
                    },
                    "id": "#metaspades.cwl/contigs_before_rr"
                },
                {
                    "label": "internal configuration file",
                    "type": "File",
                    "outputBinding": {
                        "glob": "dataset.info"
                    },
                    "id": "#metaspades.cwl/internal_config"
                },
                {
                    "label": "internal YAML data set file",
                    "type": "File",
                    "outputBinding": {
                        "glob": "input_dataset.yaml"
                    },
                    "id": "#metaspades.cwl/internal_dataset"
                },
                {
                    "label": "SPAdes log",
                    "type": "File",
                    "format": "#metaspades.cwl/text/plain",
                    "outputBinding": {
                        "glob": "spades.log"
                    },
                    "id": "#metaspades.cwl/log"
                },
                {
                    "label": "information about SPAdes parameters in this run",
                    "type": "File",
                    "format": "#metaspades.cwl/text/plain",
                    "outputBinding": {
                        "glob": "params.txt"
                    },
                    "id": "#metaspades.cwl/params"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "scaffolds.fasta"
                    },
                    "id": "#metaspades.cwl/scaffolds"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "scaffolds.paths"
                    },
                    "id": "#metaspades.cwl/scaffolds_assembly_graph"
                }
            ],
            "id": "#metaspades.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "inputs": [
                {
                    "type": "File",
                    "streamable": true,
                    "id": "#pull-SSUs.cwl/hits"
                }
            ],
            "baseCommand": [
                "grep",
                "SSU"
            ],
            "stdout": "SSUs",
            "arguments": [
                "$(inputs.hits.path)"
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#pull-SSUs.cwl/SSUs",
                    "outputBinding": {
                        "glob": "SSUs"
                    }
                }
            ],
            "id": "#pull-SSUs.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "label": "EMG assembly for paired end Illumina",
            "requirements": [
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#FragGeneScan-model.yaml/model"
                        },
                        {
                            "$import": "#InterProScan-apps.yaml/apps"
                        },
                        {
                            "$import": "#InterProScan-protein_formats.yaml/protein_formats"
                        },
                        {
                            "$import": "#esl-reformat-replace.yaml/replace"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "doc": "in Gb",
                    "id": "#main/assembly_mem_limit"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".i1f",
                        ".i1i",
                        ".i1m",
                        ".i1p"
                    ],
                    "id": "#main/covariance_model_database"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "id": "#main/forward_reads"
                },
                {
                    "type": "#FragGeneScan-model.yaml/model",
                    "id": "#main/fraggenescan_model"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "secondaryFiles": ".mscluster",
                    "id": "#main/mapseq_ref"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/mapseq_taxonomies"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "id": "#main/reverse_reads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/extract_SSUs/sequences",
                    "id": "#main/SSUs"
                },
                {
                    "type": "File",
                    "outputSource": "#main/interproscan/i5Annotations",
                    "id": "#main/annotations"
                },
                {
                    "type": "File",
                    "outputSource": "#main/classify_SSUs/classifications",
                    "id": "#main/classifications"
                },
                {
                    "type": "File",
                    "outputSource": "#main/fraggenescan/predictedCDS",
                    "id": "#main/pCDS"
                },
                {
                    "type": "File",
                    "outputSource": "#main/assembly/scaffolds",
                    "id": "#main/scaffolds"
                }
            ],
            "steps": [
                {
                    "run": "#metaspades.cwl",
                    "in": [
                        {
                            "source": "#main/forward_reads",
                            "id": "#main/assembly/forward_reads"
                        },
                        {
                            "source": "#main/assembly_mem_limit",
                            "id": "#main/assembly/memory_limit"
                        },
                        {
                            "source": "#main/reverse_reads",
                            "id": "#main/assembly/reverse_reads"
                        }
                    ],
                    "out": [
                        "#main/assembly/scaffolds"
                    ],
                    "id": "#main/assembly"
                },
                {
                    "run": "#mapseq.cwl",
                    "in": [
                        {
                            "source": "#main/mapseq_ref",
                            "id": "#main/classify_SSUs/database"
                        },
                        {
                            "source": "#main/extract_SSUs/sequences",
                            "id": "#main/classify_SSUs/sequences"
                        },
                        {
                            "source": "#main/mapseq_taxonomies",
                            "id": "#main/classify_SSUs/taxonomies"
                        }
                    ],
                    "out": [
                        "#main/classify_SSUs/classifications"
                    ],
                    "id": "#main/classify_SSUs"
                },
                {
                    "run": "#infernal-cmscan.cwl",
                    "in": [
                        {
                            "source": "#main/covariance_model_database",
                            "id": "#main/cmscan/covariance_model_database"
                        },
                        {
                            "default": true,
                            "id": "#main/cmscan/omit_alignment_section"
                        },
                        {
                            "default": true,
                            "id": "#main/cmscan/only_hmm"
                        },
                        {
                            "source": "#main/assembly/scaffolds",
                            "id": "#main/cmscan/query_sequences"
                        }
                    ],
                    "out": [
                        "#main/cmscan/matches"
                    ],
                    "id": "#main/cmscan"
                },
                {
                    "run": "#esl-sfetch-manyseqs.cwl",
                    "in": [
                        {
                            "source": "#main/index_scaffolds/sequences_with_index",
                            "id": "#main/extract_SSUs/indexed_sequences"
                        },
                        {
                            "source": "#main/get_SSU_coords/SSU_coordinates",
                            "id": "#main/extract_SSUs/names"
                        },
                        {
                            "default": true,
                            "id": "#main/extract_SSUs/names_contain_subseq_coords"
                        }
                    ],
                    "out": [
                        "#main/extract_SSUs/sequences"
                    ],
                    "id": "#main/extract_SSUs"
                },
                {
                    "run": "#FragGeneScan1_20.cwl",
                    "in": [
                        {
                            "default": true,
                            "id": "#main/fraggenescan/completeSeq"
                        },
                        {
                            "source": "#main/fraggenescan_model",
                            "id": "#main/fraggenescan/model"
                        },
                        {
                            "source": "#main/assembly/scaffolds",
                            "id": "#main/fraggenescan/sequence"
                        }
                    ],
                    "out": [
                        "#main/fraggenescan/predictedCDS"
                    ],
                    "id": "#main/fraggenescan"
                },
                {
                    "run": "#SSU-from-tablehits.cwl",
                    "in": [
                        {
                            "source": "#main/cmscan/matches",
                            "id": "#main/get_SSU_coords/table_hits"
                        }
                    ],
                    "out": [
                        "#main/get_SSU_coords/SSU_coordinates"
                    ],
                    "id": "#main/get_SSU_coords"
                },
                {
                    "run": "#esl-sfetch-index.cwl",
                    "in": [
                        {
                            "source": "#main/assembly/scaffolds",
                            "id": "#main/index_scaffolds/sequences"
                        }
                    ],
                    "out": [
                        "#main/index_scaffolds/sequences_with_index"
                    ],
                    "id": "#main/index_scaffolds"
                },
                {
                    "run": "#InterProScan5.21-60.cwl",
                    "in": [
                        {
                            "default": [
                                "Pfam",
                                "TIGRFAM",
                                "PRINTS",
                                "ProSitePatterns",
                                "Gene3D"
                            ],
                            "id": "#main/interproscan/applications"
                        },
                        {
                            "source": "#main/remove_asterisks_and_reformat/reformatted_sequences",
                            "id": "#main/interproscan/proteinFile"
                        }
                    ],
                    "out": [
                        "#main/interproscan/i5Annotations"
                    ],
                    "id": "#main/interproscan"
                },
                {
                    "run": "#esl-reformat.cwl",
                    "in": [
                        {
                            "default": {
                                "find": "*",
                                "replace": "X"
                            },
                            "id": "#main/remove_asterisks_and_reformat/replace"
                        },
                        {
                            "source": "#main/fraggenescan/predictedCDS",
                            "id": "#main/remove_asterisks_and_reformat/sequences"
                        }
                    ],
                    "out": [
                        "#main/remove_asterisks_and_reformat/reformatted_sequences"
                    ],
                    "id": "#main/remove_asterisks_and_reformat"
                }
            ],
            "id": "#main",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://schema.org/docs/schema_org_rdfa.html",
        "http://edamontology.org/EDAM_1.16.owl"
    ],
    "$namespaces": {
        "edam": "http://edamontology.org/",
        "s": "http://schema.org/"
    }
}
